==> gcc-3.4.0.tar.bz2: gcc-3.4.0/libstdc++-v3/testsuite/ext/enc_filebuf/char/13189.cc <==
// Copyright (C) 2003, 2004 Free Software Foundation
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

#ifdef _GLIBCXX_USE___ENC_TRAITS
#include <ext/enc_filebuf.h>
#endif
#include <testsuite_hooks.h>

void test01()
{
#ifdef _GLIBCXX_USE___ENC_TRAITS
  using namespace std;
  typedef __enc_traits state_type;
  typedef char char_type;
  typedef __gnu_cxx::enc_filebuf<char_type> filebuf_type;
  typedef codecvt<char_type, char, state_type> enc_codecvt;

  bool test __attribute__((unused)) = true;
  ios_base::openmode mode = ios_base::in | ios_base::out | ios_base::trunc;
  try
    {
      state_type st;
      filebuf_type fbuf(st);
      locale loc(locale::classic(), new enc_codecvt);
      fbuf.pubimbue(loc);
      fbuf.open("tmp_13189c", mode);
      fbuf.sputc('a');
      fbuf.pubseekoff(0, ios_base::beg);
      fbuf.sgetc();
      fbuf.close();
    }
  catch(...)
    {
    }
#endif
}

int main() 
{ 
  test01();
  return 0; 
}

==> gcc-4.3.1.tar.bz2: gcc-4.3.1/libstdc++-v3/testsuite/ext/enc_filebuf/char/13189.cc <==
// { dg-require-iconv "ISO-8859-1" }

// Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
// USA.

#include <testsuite_hooks.h>
#include <ext/enc_filebuf.h>

void test01()
{
  using namespace std;
  typedef char char_type;
  typedef __gnu_cxx::enc_filebuf<char_type> filebuf_type;
  typedef filebuf_type::state_type state_type;
  typedef codecvt<char_type, char, state_type> enc_codecvt;

  bool test __attribute__((unused)) = true;
  ios_base::openmode mode = ios_base::in | ios_base::out | ios_base::trunc;
  try
    {
      state_type st;
      filebuf_type fbuf(st);
      locale loc(locale::classic(), new enc_codecvt);
      fbuf.pubimbue(loc);
      fbuf.open("tmp_13189c", mode);
      fbuf.sputc('a');
      fbuf.pubseekoff(0, ios_base::beg);
      fbuf.sgetc();
      fbuf.close();
    }
  catch(...)
    {
    }
}

int main() 
{ 
  test01();
  return 0; 
}
